
.. image:: http://notario.cafepais.com/docs/_static/notario.jpg



notario
=======
A flexible and succinct Python dictionary validator with the ability to
validate against both keys *and* values. Schemas are smaller and readable
representations of data being validated.

Fully documented and thoroughly tested.

Documentation: http://notario.cafepais.com

Tested against:

* Python 2.6
* Python 2.7
* Python 3.0
* Python 3.1
* Python 3.2
* PyPy 1.5
* PyPy 1.6
* PyPy 1.7
* PyPy 1.8
* PyPy 1.9

With coverage hovering at around **99%**
